@@ -1,12 +1,12 @@
 #' Copy data model to data source
 #'
 #' @description
-#' `copy_dm_to()` takes a [dplyr::src_dbi] object or a [`DBI::DBIConnection-class`] object as its first argument
+#' `copy_dm_to()` takes a [`dplyr::src_dbi`] object or a [`DBI::DBIConnection-class`] object as its first argument
 #' and a [`dm`] object as its second argument.
 #' The latter is copied to the former.
 #' The default is to create temporary tables, set `temporary = FALSE` to create permanent tables.
 #' Unless `set_key_constraints` is `FALSE`, primary key constraints are set on all databases,
-#' and in addition foreign key constraints are set on MSSQL and Postgres databases.
+#' and in addition foreign key constraints are set on MSSQL and Postgres/Redshift databases.
 #'
 #' @inheritParams dm_examine_constraints
 #'
@@ -24,7 +24,7 @@
 #'
 #'   Not all DBMS are supported.
 #' @param table_names Desired names for the tables on `dest`; the names within the `dm` remain unchanged.
-#'   Can be `NULL`, a named character vector, or a vector of [DBI::Id] objects.
+#'   Can be `NULL`, a named character vector, or a vector of [`DBI::Id`] objects.
 #'
 #'   If left `NULL` (default), the names will be determined automatically depending on the `temporary` argument:
 #'
@@ -280,7 +280,7 @@ db_append_table <- function(con, remote_table, table, progress, top_level_fun =
       }
       DBI::dbExecute(con, sql, immediate = TRUE)
     }))
-  } else if (is_postgres(con)) {
+  } else if (is_postgres(con) || is_redshift(con)) {
     # https://github.com/r-dbi/RPostgres/issues/384
     table <- as.data.frame(table)
     # https://github.com/r-dbi/RPostgres/issues/382
