@@ -1,5 +1,5 @@
 #' Connection to SQL Financial Database
-#' @description Connects to relational.fit.cvut.cz unless the service is
+#' @description Connects to relational.fel.cvut.cz unless the service is
 #' unavailable, in which case databases.pacha.dev is used as a fallback
 #' @return A `MariaDBConnection` object
 #' @noRd
@@ -12,7 +12,7 @@ financial_db_con <- function() {
   err_dbedu <- tryCatch(return(dbedu_con()), error = identity)
 
   abort(paste0(
-    "Can't connect to relational.fit.cvut.cz or databases.pacha.dev:\n",
+    "Can't connect to relational.fel.cvut.cz or databases.pacha.dev:\n",
     conditionMessage(err_relational), "\n",
     conditionMessage(err_dbedu)
   ))
@@ -22,9 +22,9 @@ relational_con <- function() {
   DBI::dbConnect(
     RMariaDB::MariaDB(),
     username = "guest",
-    password = "relational",
+    password = "ctu-relational",
     dbname = "Financial_ijs",
-    host = "relational.fit.cvut.cz"
+    host = "relational.fel.cvut.cz"
   )
 }
 
