@@ -33,8 +33,6 @@ test_that("`dm_examine_constraints()` works", {
 test_that("output", {
   skip_if_ide()
 
-  skip_if_not_installed("nycflights13")
-
   expect_snapshot({
     dm() %>% dm_examine_constraints()
 
@@ -53,8 +51,6 @@ test_that("output", {
 test_that("output as tibble", {
   skip_if_ide()
 
-  skip_if_not_installed("nycflights13")
-
   expect_snapshot({
     dm_nycflights_small_cycle() %>%
       dm_examine_constraints() %>%
@@ -92,7 +88,9 @@ test_that("`dm_examine_constraints()` API", {
     dm_examine_constraints(dm_test_obj(), progress = FALSE)
     dm_examine_constraints(dm = dm_test_obj())
   })
+})
 
+test_that("`dm_examine_constraints()` API (2)", {
   expect_snapshot(error = TRUE, {
     dm_examine_constraints(dm_test_obj(), foo = "bar")
   })
