@@ -1,5 +1,6 @@
 test_that("Standard learning from MSSQL (schema 'dbo') or Postgres (schema 'public') and get_src_tbl_names() works?", {
   skip_if_schema_not_supported()
+  skip_if(identical(Sys.getenv("R_COVR"), "true"))
 
   # dm_learn_from_mssql() --------------------------------------------------
   con_db <- my_test_con()
@@ -218,12 +219,12 @@ test_that("Learning from MSSQL (schema 'dbo') on other DB works?", {
   DBI::dbExecute(con_db, "CREATE DATABASE test_database_dm")
   DBI::dbWriteTable(
     con_db,
-    DBI::Id(db = "test_database_dm", schema = "dbo", table = "test_1"),
+    DBI::Id(catalog = "test_database_dm", schema = "dbo", table = "test_1"),
     value = tibble(a = c(5L, 5L, 4L, 2L, 1L), b = 1:5)
   )
   DBI::dbWriteTable(
     con_db,
-    DBI::Id(db = "test_database_dm", schema = "dbo", table = "test_2"),
+    DBI::Id(catalog = "test_database_dm", schema = "dbo", table = "test_2"),
     value = tibble(c = c(1L, 1L, 1L, 5L, 4L), d = c(10L, 11L, 10L, 10L, 11L))
   )
   # set PK
@@ -285,6 +286,12 @@ test_that("Learning from a specific schema in another DB for MSSQL works?", {
 
   original_dbname <- attributes(con_db)$info$dbname
 
+  # delete database after test
+  withr::defer({
+    # dropping tables and schema is unnecessary
+    try(DBI::dbExecute(con_db, "DROP DATABASE test_database_dm"))
+  })
+
   # create another DB, a schema and 2 connected tables
   DBI::dbExecute(con_db, "CREATE DATABASE test_database_dm")
   DBI::dbExecute(con_db, "USE test_database_dm")
@@ -293,12 +300,12 @@ test_that("Learning from a specific schema in another DB for MSSQL works?", {
 
   DBI::dbWriteTable(
     con_db,
-    DBI::Id(db = "test_database_dm", schema = "dm_test", table = "test_1"),
+    DBI::Id(catalog = "test_database_dm", schema = "dm_test", table = "test_1"),
     value = tibble(a = c(5L, 5L, 4L, 2L, 1L), b = 1:5)
   )
   DBI::dbWriteTable(
     con_db,
-    DBI::Id(db = "test_database_dm", schema = "dm_test", table = "test_2"),
+    DBI::Id(catalog = "test_database_dm", schema = "dm_test", table = "test_2"),
     value = tibble(c = c(1L, 1L, 1L, 5L, 4L), d = c(10L, 11L, 10L, 10L, 11L))
   )
   # set PK
@@ -311,14 +318,6 @@ test_that("Learning from a specific schema in another DB for MSSQL works?", {
   )
 
 
-  # delete database after test
-  withr::defer({
-    try(DBI::dbExecute(con_db, "DROP TABLE [test_database_dm].[dm_test].[test_2]"))
-    try(DBI::dbExecute(con_db, "DROP TABLE [test_database_dm].[dm_test].[test_1]"))
-    # dropping schema is unnecessary
-    try(DBI::dbExecute(con_db, "DROP DATABASE test_database_dm"))
-  })
-
   # test 'get_src_tbl_names()'
   expect_identical(
     get_src_tbl_names(con_db, schema = "dm_test", dbname = "test_database_dm"),
@@ -449,9 +448,9 @@ test_that("dm_from_con() with mariaDB", {
   my_db <- RMariaDB::dbConnect(
     RMariaDB::MariaDB(),
     username = "guest",
-    password = "relational",
+    password = "ctu-relational",
     dbname = "Financial_ijs",
-    host = "relational.fit.cvut.cz"
+    host = "relational.fel.cvut.cz"
   )
   expect_snapshot_output(my_dm <- dm_from_con(my_db))
   expect_snapshot(dm::dm_get_all_fks(my_dm))
